pub struct BlockRef { /* private fields */ }Expand description
An external block reference that is owned by and can be passed between validator components.
Implements the Drop trait to allow for automatically decrementing the external reference
count for the block ID in the block manager.
Implementations