pub struct StaticExecutionAdapter { /* private fields */ }Expand description
The StaticExecutionAdapter to wrap TransactionHandlers
This struct takes a series of transaction handlers which can be used to execution transactions. These transactions are executed on a single background thread.
Implementations
Sourceimpl StaticExecutionAdapter
impl StaticExecutionAdapter
Sourcepub fn new_adapter(
handlers: Vec<Box<dyn TransactionHandler>>,
context_manager: ContextManager,
) -> Result<Self, ExecutionAdapterError>
pub fn new_adapter( handlers: Vec<Box<dyn TransactionHandler>>, context_manager: ContextManager, ) -> Result<Self, ExecutionAdapterError>
Creates a new adapter, if possible.
Creates a StaticExecutionAdapter wrapping the given TransactionHandler vector and a
ContextManager instance. This adapter will dispatch transaction pairs to the appropriate
handler, if found.
Errors
ExecutionAdapterError is returned if the background thread cannot be created.